summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMatthias Hecker <mail@apoc.cc>2020-04-13 20:39:48 +0200
committerMatthias Hecker <mail@apoc.cc>2020-04-13 20:39:48 +0200
commitf287bf1e73829434d92b46c333c3185373198518 (patch)
tree46e4df04f4e6f7442654794e2720679dd0e0cded
parentd19058b6c071d754a6cc8143acd7e2c50ae12d93 (diff)
message: add #thanks method, similar to okay
-rw-r--r--lib/rbot/message.rb19
-rw-r--r--test/mock.rb4
2 files changed, 15 insertions, 8 deletions
diff --git a/test/mock.rb b/test/mock.rb
index ba6326db..30c4ffab 100644
--- a/test/mock.rb
+++ b/test/mock.rb
@@ -77,6 +77,10 @@ class MockMessage
reply 'okay'
end
+ def thanks
+ reply 'thanks :)'
+ end
+
def public?
true
end
diff --git a/lib/rbot/message.rb b/lib/rbot/message.rb
index ed533e9b..155f9038 100644
--- a/lib/rbot/message.rb
+++ b/lib/rbot/message.rb
@@ -474,15 +474,14 @@ module Irc
@bot.ctcp_notice @source, @ctcp, string, options
end
- # convenience method to reply "okay" in the current language to the
- # message
- def plainokay
- self.reply @bot.lang.get("okay"), :nick => false
+ # convenience method to reply a literal message in the current language to the message
+ def plain_literal(ident)
+ self.reply @bot.lang.get(ident), :nick => false
end
# Like the above, but append the username
- def nickokay
- str = @bot.lang.get("okay").dup
+ def nick_literal(ident)
+ str = @bot.lang.get(ident).dup
if self.public?
# remove final punctuation
str.gsub!(/[!,.]$/,"")
@@ -492,9 +491,13 @@ module Irc
end
# the default okay style is the same as the default reply style
- #
def okay
- @bot.config['core.reply_with_nick'] ? nickokay : plainokay
+ @bot.config['core.reply_with_nick'] ? nick_literal('okay') : plain_literal('okay')
+ end
+
+ # thanks the user in reply
+ def thanks
+ @bot.config['core.reply_with_nick'] ? nick_literal('thanks') : plain_literal('thanks')
end
# send a NOTICE to the message source